==> adfurikun-1.0.1.tar.gz: lib/reward.dart <==
import 'dart:io';
import 'package:flutter/services.dart';
import 'constants.dart';
import 'ad_base.dart';
import 'adfurikun_plugin.dart';

enum AdfurikunRewardCallback {
  onPrepareSuccess,
  onPrepareFailure,
  onStartPlaying,
  onFinishedPlaying,
  onAdClose,
  onFailedPlaying
}

typedef AdfurikunRewardListener(
    AdfurikunRewardCallback? callback,
    String? appId,
    String? adNetworkKey,
    int? errorCode);

class AdfurikunReward extends AdfurikunAdBase {
  AdfurikunRewardListener? listener;

  Map<String, AdfurikunRewardCallback> _callbackMap = {
    CALLBACK_ON_PREPARE_SUCCESS: AdfurikunRewardCallback.onPrepareSuccess,
    CALLBACK_ON_PREPARE_FAILURE: AdfurikunRewardCallback.onPrepareFailure,
    CALLBACK_ON_START_PLAYING: AdfurikunRewardCallback.onStartPlaying,
    CALLBACK_ON_FINISHED_PLAYING: AdfurikunRewardCallback.onFinishedPlaying,
    CALLBACK_ON_AD_CLOSE: AdfurikunRewardCallback.onAdClose,
    CALLBACK_ON_FAILED_PLAYING: AdfurikunRewardCallback.onFailedPlaying
  };

  AdfurikunReward(String appId) : super(appId, AD_TYPE_REWARD) {
    AdfurikunPlugin.invoke(method(METHOD_INIT), args());
  }

  void load() {
    AdfurikunPlugin.invoke(method(METHOD_LOAD), args());
  }

  void play() {
    AdfurikunPlugin.invoke(method(METHOD_PLAY), args());
  }

  Future<bool> isPrepared() async {
    return await AdfurikunPlugin.invokeReturnBool(method(METHOD_IS_PREPARED), args());
  }

  void resume() {
    if (Platform.isAndroid) {
      AdfurikunPlugin.invoke(method(METHOD_RESUME), args());
    }
  }

  void pause() {
    if (Platform.isAndroid) {
      AdfurikunPlugin.invoke(method(METHOD_PAUSE), args());
    }
  }

  @override
  void destroy() {
    super.destroy();
    AdfurikunPlugin.invoke(method(METHOD_DESTROY), args());
  }

  @override
  void notifyListener(MethodCall call) {
    if (listener != null) {
      AdfurikunRewardCallback? callback = _callbackMap[call.method];
      String? appId = call.arguments[KEY_APP_ID];
      String? adNetworkKey = call.arguments[KEY_AD_NETWORK_KEY];
      int? errorCode = call.arguments[KEY_ERROR_CODE];
      listener!(callback, appId, adNetworkKey, errorCode);
    } else {
      print('AdfurikunRewardListener is null');
    }
  }
}

==> adfurikun-1.2.0.tar.gz: lib/reward.dart <==
import 'dart:io';
import 'package:flutter/services.dart';
import 'constants.dart';
import 'ad_base.dart';
import 'adfurikun_plugin.dart';

enum AdfurikunRewardCallback {
  onPrepareSuccess,
  onPrepareFailure,
  onStartPlaying,
  onFinishedPlaying,
  onAdClose,
  onFailedPlaying
}

typedef AdfurikunRewardListener(
    AdfurikunRewardCallback? callback,
    String? appId,
    String? adNetworkKey,
    int? errorCode);

class AdfurikunReward extends AdfurikunAdBase {
  AdfurikunRewardListener? listener;

  Map<String, AdfurikunRewardCallback> _callbackMap = {
    CALLBACK_ON_PREPARE_SUCCESS: AdfurikunRewardCallback.onPrepareSuccess,
    CALLBACK_ON_PREPARE_FAILURE: AdfurikunRewardCallback.onPrepareFailure,
    CALLBACK_ON_START_PLAYING: AdfurikunRewardCallback.onStartPlaying,
    CALLBACK_ON_FINISHED_PLAYING: AdfurikunRewardCallback.onFinishedPlaying,
    CALLBACK_ON_AD_CLOSE: AdfurikunRewardCallback.onAdClose,
    CALLBACK_ON_FAILED_PLAYING: AdfurikunRewardCallback.onFailedPlaying
  };

  AdfurikunReward(String appId) : super(appId, AD_TYPE_REWARD) {
    AdfurikunPlugin.invoke(method(METHOD_INIT), argsWithPluginVersion());
  }

  void load() {
    AdfurikunPlugin.invoke(method(METHOD_LOAD), args());
  }

  void play() {
    AdfurikunPlugin.invoke(method(METHOD_PLAY), args());
  }

  Future<bool> isPrepared() async {
    return await AdfurikunPlugin.invokeReturnBool(method(METHOD_IS_PREPARED), args());
  }

  void resume() {
    if (Platform.isAndroid) {
      AdfurikunPlugin.invoke(method(METHOD_RESUME), args());
    }
  }

  void pause() {
    if (Platform.isAndroid) {
      AdfurikunPlugin.invoke(method(METHOD_PAUSE), args());
    }
  }

  @override
  void destroy() {
    super.destroy();
    AdfurikunPlugin.invoke(method(METHOD_DESTROY), args());
  }

  @override
  void notifyListener(MethodCall call) {
    if (listener != null) {
      AdfurikunRewardCallback? callback = _callbackMap[call.method];
      String? appId = call.arguments[KEY_APP_ID];
      String? adNetworkKey = call.arguments[KEY_AD_NETWORK_KEY];
      int? errorCode = call.arguments[KEY_ERROR_CODE];
      listener!(callback, appId, adNetworkKey, errorCode);
    } else {
      print('AdfurikunRewardListener is null');
    }
  }
}
